from bot.config import FEEDBACK_CHAT_ID
from bot.announce import edit_announce
from bot.api import telegram_api
import logging
from store import get_all_removed

logger = logging.getLogger(__name__)
logging.basicConfig(level=logging.INFO)

start_message = {
    'en': "Welcome home! You can type any message here to be passed to chat",
    'ru': "Доброе утро! Можешь напечатать здесь любое сообщение для передачи в чат"
}


async def handle_private(msg, state):
    text = msg.get("text")
    sender = msg.get("from", {})
    uid = sender.get("id")
    lang = sender.get("language_code", "ru")
    if lang != "ru" and lang != "en":
        lang = "en"
    if text.startswith("/"):
        if text == '/start':
            await telegram_api("sendMessage", chat_id=uid, text=start_message[lang])
        elif text.startswith('/message'):
            await edit_announce(msg)
            return
        elif text.startswith('/toxic'):
            toxic_score = get_average_toxic(msg)
            text = f"Средняя токсичность сообщений: {toxic_score}%"
            await telegram_api("sendMessage", chat_id=uid, reply_to_message_id=msg.get("message_id"), text=text)
            return
        elif text == '/removed':
            removed_messages = await get_all_removed(uid)
            if removed_messages:
                await telegram_api("sendMessage", chat_id=uid, text="\n\n".join(removed_messages))
            return

    await telegram_api("forwardMessage", from_chat_id=sender.get("id"), message_id=msg.get("message_id"), chat_id=FEEDBACK_CHAT_ID)
